# equit-ease

Access up-to-date pricing, volume, and chart-based data for any valid company name or ticker symbol. This project is under rapid development and is updated daily. Release information will be specified in the coming weeks.

This project is for you if:
- you enjoy following the markets, and pay attention to how current events influence short-term pricing and volume
- you spend a majority of your time in the terminal, and want a sleek command-line utility to access recent pricing, volume, and chart data
